# code-20210109-saurabhkhare
Python BMI Calculator Offline Coding Challenge V7


# Objective :
1. Read the JSON raw data and created new fields for BMI
2. Find out the total number of overweight people.

# Prerequisites:
1.Use bmi_package
2.Python Libraries needed : pandas,json,setuptools 

# Usage :
A sample usage has been shown in run.py where:
1. Raw data is read and updated Table is returned.
2. Total number of overweight people is returned.
3. Validation test cases are also taken care here.